Improve this Doc

# `ngCookies`

## Installation

First, get the file:

- Google CDN e.g.

      "//ajax.googleapis.com/ajax/libs/angularjs/X.Y.Z/angular-cookies.js"

- NPM e.g.

      npm install --save angular-cookies@X.Y.Z

  or

      yarn add angular-cookies@X.Y.Z

- Bower e.g.

      bower install angular-cookies#X.Y.Z

- code.angularjs.org (discouraged for production use) e.g.

      "//code.angularjs.org/X.Y.Z/angular-cookies.js"

where X.Y.Z is the AngularJS version you are running.

Then, include `angular-cookies.js` in your HTML:

    <script src="path/to/angular.js"></script>
    <script src="path/to/angular-cookies.js"></script>

Finally, load the module in your application by adding it as a dependent module:

    angular.module('app', ['ngCookies']);

With that you're ready to get started!

# ngCookies

The `ngCookies` module provides a convenient wrapper for reading and writing browser cookies.

See `$cookies` for usage.

## Module Components

### Provider

Name | Description
--- | ---
$cookiesProvider | Use `$cookiesProvider` to change the default behavior of the $cookies service.

### Service

Name | Description
--- | ---
$cookies | Provides read/write access to browser's cookies.
$cookieStore | Provides a key-value (string-object) storage, that is backed by session cookies. Objects put or retrieved from this storage are automatically serialized or deserialized by angular's toJson/fromJson.